@@ -3,6 +3,7 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 from __future__ import division, print_function
 
+import re
 from functools import wraps
 
 import numpy as np
@@ -13,7 +14,7 @@ from .pymbd import _array, from_volumes
 try:
     from ._libmbd import ffi as _ffi, lib as _lib
 except ImportError:
-    raise Exception('Pymbd C extension unimportable, cannot use Fortran')
+    raise Exception('Pymbd C extension unimportable, cannot use Fortran') from None
 
 __all__ = ['MBDGeom', 'with_mpi', 'with_scalapack']
 
@@ -27,6 +28,7 @@ LIBMBD_VERSION = (
     _lib.cmbd_version_major,
     _lib.cmbd_version_minor,
     _lib.cmbd_version_patch,
+    _ffi.string(_lib.cmbd_version_suffix).strip().decode(),
 )
 
 # do not test versions when running autodoc
@@ -36,14 +38,14 @@ if PYMBD_VERSION and isinstance(LIBMBD_VERSION[0], int):
         assert PYMBD_VERSION[1] == LIBMBD_VERSION[1]
     else:
         assert PYMBD_VERSION[1] <= LIBMBD_VERSION[1]
-
-if with_mpi:
-    from mpi4py import MPI  # noqa
+    if len(PYMBD_VERSION) == 4:
+        git_commit = re.split('[+-]', PYMBD_VERSION[3])[1]
+        assert LIBMBD_VERSION[3].endswith(git_commit)
 
 
-class MBDFortranException(Exception):
+class MBDFortranError(Exception):
     def __init__(self, code, origin, msg):
-        super(MBDFortranException, self).__init__(msg)
+        super(MBDFortranError, self).__init__(msg)
         self.code = code
         self.origin = origin
 
@@ -127,7 +129,7 @@ class MBDGeom(object):
         msg = _ffi.new('char[150]')
         _lib.cmbd_get_exception(self._geom_f, _cast('int*', code), origin, msg)
         if code != 0:
-            raise MBDFortranException(
+            raise MBDFortranError(
                 int(code), _ffi.string(origin).decode(), _ffi.string(msg).decode()
             )
 
@@ -153,6 +155,10 @@ class MBDGeom(object):
         """Whether structure is a crystal."""
         return self._lattice is not None
 
+    def print_timing(self):
+        """Print timing from Libmbd."""
+        _lib.cmbd_print_timing(self._geom_f)
+
     @_auto_context
     def ts_energy(self, alpha_0, C6, R_vdw, sR, d=20.0, damping='fermi', force=False):
         """Calculate a TS energy.
